@@ -1,11 +1,12 @@
-#!/usr/bin/python3.9
+#!/usr/bin/python3.9.exe
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdal_sieve as a convenience to use as a script
 from osgeo_utils.gdal_sieve import *  # noqa
 from osgeo_utils.gdal_sieve import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdal_sieve')
+deprecation_warn("gdal_sieve")
 sys.exit(main(sys.argv))
